Learn R Programming

Rforestry (version 0.11.1.0)

CppToR_translator: Cpp to R translator

Description

Add more trees to the existing forest.

Usage

CppToR_translator(object)

Value

A list of lists. Each sublist contains the information to span a tree.

Arguments

object

external CPP pointer that should be translated from Cpp to an R object