Learn R Programming

Rforestry (version 0.11.1.0)

relinkCPP_prt: relink CPP ptr

Description

When a `foresty` object is saved and then reloaded the Cpp pointers for the data set and the Cpp forest have to be reconstructed

Usage

relinkCPP_prt(object)

Arguments

object

an object of class `forestry` or class `multilayerForestry`