powered by
When a `foresty` object is saved and then reloaded the Cpp pointers for the data set and the Cpp forest have to be reconstructed
relinkCPP_prt(object)
an object of class `forestry` or class `multilayerForestry`